==> json-to-table-pagination-1.2.0.tgz: package/README.md <==
# json-to-table-pagination

When an array of JSON objects is passed to json-to-table-pagination, it will return the json values in a table format
and adds pagination to it.

1. Pass an array of objects, it will return a reactjs component with table and pagination
2. Can select number of rows in a table per page
3. Can go to any page number
4. Click on any column header to sort in ascending/descending order
5. Customize header background color
6. Can select either arrows or text in pagination

[![NPM](https://img.shields.io/npm/v/json-to-table-pagination.svg)](https://www.npmjs.com/package/json-to-table-pagination) [![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)

## Install

```bash
npm install --save json-to-table-pagination
```

## Usage

```jsx
import React from 'react'
import { JSONToTable } from 'json-to-table-pagination'

const App = () => {
    const users = [
        {
            id: '111',
            firstname: 'Ram',
            lastname: 'Akunuru',
            email: 'ram@gmail.com'
        },
        {
            id: '222',
            firstname: 'Tony',
            lastname: 'Stark',
            email: 'tony@gmail.com'
        },
        {
            id: '333',
            firstname: 'Captain',
            lastname: 'America',
            email: 'captain@gmail.com'
        },
        ...
    ]
    const options = {
        bgColor: '#1B5E20',
        useArrowIcons: false
    }

    return <JSONToTable jsonFile={users} options={options} />
}

export default App
```

![Alt text](https://github.com/RamAkunuru/images/blob/master/blue.png?raw=true 'Blue Table')
![Alt text](https://github.com/RamAkunuru/images/blob/master/green.png?raw=true 'Green Table')

## License

MIT © [](https://github.com/)

==> json-to-table-pagination-1.2.1.tgz: package/README.md <==
# json-to-table-pagination

When an array of JSON objects is passed to json-to-table-pagination, it will return the json values in a table format
and adds pagination to it.

1. Pass an array of objects, it will return a reactjs component with table and pagination
2. Can select number of rows in a table per page
3. Can go to any page number
4. Click on any column header to sort in ascending/descending order
5. Customize header background color
6. Customize pagination arrows by showing either arrows or text in pagination
7. Click on any value in the table and the value gets highlighted so that it can be copied easily

[![NPM](https://img.shields.io/npm/v/json-to-table-pagination.svg)](https://www.npmjs.com/package/json-to-table-pagination) [![JavaScript Style Guide](https://img.shields.io/badge/code_style-standard-brightgreen.svg)](https://standardjs.com)

## Install

```bash
npm install --save json-to-table-pagination
```

## Usage

```jsx
import React from 'react'
import { JSONToTable } from 'json-to-table-pagination'

const App = () => {
    const users = [
        {
            id: '111',
            firstname: 'Ram',
            lastname: 'Akunuru',
            email: 'ram@gmail.com'
        },
        {
            id: '222',
            firstname: 'Tony',
            lastname: 'Stark',
            email: 'tony@gmail.com'
        },
        {
            id: '333',
            firstname: 'Captain',
            lastname: 'America',
            email: 'captain@gmail.com'
        },
        ...
    ]
    const options = {
        bgColor: '#1B5E20',
        useArrowIcons: false
    }

    return <JSONToTable jsonFile={users} options={options} />
}

export default App
```

![Alt text](https://github.com/RamAkunuru/images/blob/master/blue.png?raw=true 'Blue Table')
![Alt text](https://github.com/RamAkunuru/images/blob/master/green.png?raw=true 'Green Table')

## License

MIT © [](https://github.com/)
